<?php
/**
 * @file
 * Defines the ControllerMenuItemsManager.
 */

/**
 * The ControllerMenuItemsManager responsible for providing list
 * of menu items for one or more modules.
 */
class ControllerMenuItemsManager {
  /**
   * Returns list of menu items that defined by the controllers
   * for the one module or for the list of modules.
   *
   * @param string|array $module_list
   *   It can be either array of module names or string, containing
   *   module name.
   *
   * @return array
   */
  public static function getNormalizedMenuItems($module_list = NULL) {
    if (NULL === $module_list) {
      $module_list = controller_get_module_list();
    }
    elseif (!is_array($module_list)) {
      $module_list = array($module_list);
    }
    $menu_items = self::collectMenuItems($module_list);
    return self::normalizeMenuItems($menu_items);
  }

  /**
   * Collects and returns non-normalized menu items for the specified
   * module list.
   */
  protected static function collectMenuItems(array $module_list) {
    $items = array();
    require_once drupal_get_path('module', 'controller') . '/services/MenuItemsCollector.php';
    $collector = new ControllerMenuItemsCollector();
    foreach ($module_list as $module_name) {
      $items = array_merge($items, $collector->getMenuItemsForModule($module_name));
    }
    return $items;
  }

  /**
   * Makes all menu items 'normal' to follow Drupal's conventions.
   *
   * @return array
   */
  protected static function normalizeMenuItems(array $items) {
    require_once drupal_get_path('module', 'controller') . '/services/MenuItemsNormalizer.php';
    $normalizer = new ControllerMenuItemsNormalizer();
    return $normalizer->normalizeMenuItems($items);
  }
}