<?php
/**
 * @file
 * Defines the ControllerNamingService class.
 */

class ControllerNamingService {
  protected static $moduleListWithoutNs;

  /**
   * Creates a full class name for the specified controller.
   */
  static function createFullClassName($module_name, $controller_name) {
    $ns_prefix = self::camelize($module_name, TRUE);
    $controller_name = self::camelize($controller_name, TRUE);
    if (self::nsShouldBeUsed($module_name)) {
      $class_name = '\\' . $ns_prefix . '\\' . $controller_name;
    }
    else {
      $class_name = $ns_prefix . $controller_name;
    }
    return $class_name;
  }

  /**
   * Initializes class again and resets all inner caches.
   */
  static function init() {
    self::$moduleListWithoutNs = NULL;
  }

  /**
   * Does camelization of string.
   */
  protected static function camelize($string, $pascal_case = FALSE) {
    $string = str_replace(array('-', '_'), ' ', $string);
    $string = ucwords($string);
    $string = str_replace(' ', '', $string);

    if (!$pascal_case) {
      return lcfirst($string);
    }
    return $string;
  }

  /**
   * Returns either namespace should be used or not.
   */
  protected static function nsShouldBeUsed($module_name) {
    $use_namespaces = variable_get('controller_use_ns', 0);
    if (!$use_namespaces) {
      return FALSE;
    }
    if (NULL === self::$moduleListWithoutNs) {
      self::$moduleListWithoutNs = array_unique(array_merge(
        module_invoke_all('controller_no_ns'),
        array('controller')
      ));
    }
    return !in_array($module_name, self::$moduleListWithoutNs);
  }
}
